#pragma once
# ifndef GLOBAL_H
# define GLOBAL_H
/* --------------------------------------------------------------------------
 * Copyright (C) 1989, 1991-2021 Free Software Foundation.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * See http://www.gnu.org/licenses/ for the GNU General License.
 * ---------------------------------------------------------------------------*/

/**
 * @author A. Schwarz
 * @file      Global.h
 *
 * @brief Contains gloabal data referenced by one or more classes.
*/

# include <map>
# include <vector>

# include "header/AbstractAssetInput.h"
# include "header/AssetID.h"
# include "header/Gawk.h"
# include "header/HOAAnalysis.h"
# include "header/InflationData.h"

using namespace gawk;

using ADI = AbstractAssetInput;

extern bool debug;                                       //!< debug flag
extern Gawk *g;                                          //!< pointer to Gawk object       

extern vector<InflationData> inflationdata;
extern vector<AssetID*> audited_assets;                  //!< asset#:asset name/ID's for audited data
extern vector<AssetID*> rda_assets;                      //!< asset#:asset name/ID's for rda data
extern vector<AssetID*> unaudited_assets;                //!< asset#:asset name/ID's for unaudited data
extern vector<ADI::YearData*>* audited_reports;          //!< audited budget reports by year
extern vector<ADI::YearData*>* rda_reports;              //!< rda reports by year
extern vector<ADI::YearData*>* unaudited_reports;        //!< unaudited budget reports by year
extern map<long long int, AssetID*> audited_map;         //!< Audited categories and assets
extern map<long long int, AssetID*> rda_map;             //!< RDA categories and assets
extern map<long long int, AssetID*> unaudited_map;       //!< Unaudited categories and assets

#endif /* GLOBAL_H */
